@@ -4,11 +4,13 @@ NAME = "BLAKE2b"
 SUFFIX = ".blake2b"
 
 
-@gethashcli(NAME)
+@gethashcli(NAME, SUFFIX)
 def main(check, files, **kwargs):
+    """Generate and check BLAKE2b."""
+
     from hashlib import blake2b as H
 
-    script_main(H(), SUFFIX, check, files, **kwargs)
+    script_main(H(), check, files, **kwargs)
 
 
 if __name__ == "__main__":
