@@ -4,11 +4,13 @@ NAME = "BLAKE2s"
 SUFFIX = ".blake2s"
 
 
-@gethashcli(NAME)
+@gethashcli(NAME, SUFFIX)
 def main(check, files, **kwargs):
+    """Generate and check BLAKE2s."""
+
     from hashlib import blake2s as H
 
-    script_main(H(), SUFFIX, check, files, **kwargs)
+    script_main(H(), check, files, **kwargs)
 
 
 if __name__ == "__main__":
