@@ -4,11 +4,13 @@ NAME = "MD2"
 SUFFIX = ".md2"
 
 
-@gethashcli(NAME)
+@gethashcli(NAME, SUFFIX)
 def main(check, files, **kwargs):
+    """Generate and check MD2."""
+
     from Cryptodome.Hash.MD2 import new as H
 
-    script_main(H(), SUFFIX, check, files, **kwargs)
+    script_main(H(), check, files, **kwargs)
 
 
 if __name__ == "__main__":
