@@ -4,11 +4,13 @@ NAME = "MD5"
 SUFFIX = ".md5"
 
 
-@gethashcli(NAME)
+@gethashcli(NAME, SUFFIX)
 def main(check, files, **kwargs):
+    """Generate and check MD5."""
+
     from hashlib import md5 as H
 
-    script_main(H(), SUFFIX, check, files, **kwargs)
+    script_main(H(), check, files, **kwargs)
 
 
 if __name__ == "__main__":
