@@ -4,11 +4,13 @@ NAME = "SHA1"
 SUFFIX = ".sha1"
 
 
-@gethashcli(NAME)
+@gethashcli(NAME, SUFFIX)
 def main(check, files, **kwargs):
+    """Generate and check SHA1."""
+
     from hashlib import sha1 as H
 
-    script_main(H(), SUFFIX, check, files, **kwargs)
+    script_main(H(), check, files, **kwargs)
 
 
 if __name__ == "__main__":
